@@ -3,11 +3,13 @@ from etl_bq_tools.utils import constants as cons
 
 
 def bq_set_project(project_id=None, logging=None):
-    """
+    """This method is for set a project
+
      :param project_id: String
      :param logging: Object
-     :return:
+     :return: True
     """
+
     import os
     from color_tools import cprint
 
@@ -22,21 +24,24 @@ def bq_set_project(project_id=None, logging=None):
             cprint(cons.txt_set_project_success.format(project_id), 'yellow')
         else:
             cprint(cons.txt_set_project_success.format(project_id), 'yellow')
+        return True
     except:
         if logging:
             logging.info(cons.txt_set_project_errors.format(project_id))
             cprint(cons.txt_set_project_errors.format(project_id), 'yellow')
         else:
             cprint(cons.txt_set_project_errors.format(project_id), 'yellow')
+        return None
 
 
 @get_time_function_execution
 def bq_execute_sql(sql=None, parameter=None, logging=None):
-    """
+    """This method is for execute a file with extension .sql
+
      :param sql: file.sql
      :param parameter: list dict params [{"variable": "", "type": "", "value":""}]
      :param logging: object
-     :return:
+     :return: True
     """
 
     import os
@@ -69,10 +74,11 @@ def bq_execute_sql(sql=None, parameter=None, logging=None):
             cprint(cons.txt_execute_sql_success.format(file_sql), 'yellow')
         else:
             cprint(cons.txt_execute_sql_success.format(file_sql), 'yellow')
-
+        return True
     except Exception as e:
         if logging:
             logging.info(cons.txt_execute_sql_errors.format(file_sql))
             cprint(cons.txt_execute_sql_errors.format(file_sql), 'yellow')
         else:
             cprint(cons.txt_execute_sql_errors.format(file_sql), 'yellow')
+        return None
