@@ -4,6 +4,7 @@ from etl_bq_tools.utils.memory import get_reduce_memory
 
 def gs_bucket_list_objects(project_id, bucket_name,
                            bucket_prefix=None,
+                           subdir=False,
                            prefix_start=None, prefix_end=None,
                            logging=None, key_path=None):
     """This method is for iterate object in the bucket
@@ -11,6 +12,7 @@ def gs_bucket_list_objects(project_id, bucket_name,
     :param project_id: String
     :param bucket_name: String
     :param bucket_prefix: String
+    :param subdir: Boolean
     :param prefix_start: String
     :param prefix_end: String
     :param logging: Object
@@ -33,6 +35,7 @@ def gs_bucket_list_objects(project_id, bucket_name,
     try:
         bucket = client.get_bucket(bucket_name)
         blobs = bucket.list_blobs(prefix=bucket_prefix)
+        subdir_len = len(str(bucket_prefix).split("/")) + 1
 
         filenames = list()
         if prefix_start and not prefix_end:
@@ -49,6 +52,9 @@ def gs_bucket_list_objects(project_id, bucket_name,
         elif not prefix_start and not prefix_start:
             filenames = list([blob for blob in blobs])
 
+        if subdir:
+            filenames = [filename for filename in filenames if len(str(filename).split("/")) == subdir_len]
+
         if logging:
             logging.info(cons.txt_gs_bucket_list_objects_success.format(bucket_name))
             cprint(cons.txt_gs_bucket_list_objects_success.format(bucket_name), 'yellow')
@@ -66,6 +72,7 @@ def gs_bucket_list_objects(project_id, bucket_name,
 
 def gs_bucket_list_patterns(project_id, bucket_name,
                             bucket_prefix=None,
+                            subdir=False,
                             prefix_start=None, prefix_end=None,
                             logging=None, key_path=None):
     """This method is for iterate object in the bucket
@@ -73,6 +80,7 @@ def gs_bucket_list_patterns(project_id, bucket_name,
     :param project_id: String
     :param bucket_name: String
     :param bucket_prefix: String
+    :param subdir: Boolean
     :param prefix_start: String
     :param prefix_end: String
     :param logging: Object
@@ -95,6 +103,7 @@ def gs_bucket_list_patterns(project_id, bucket_name,
     try:
         bucket = client.get_bucket(bucket_name)
         blobs = bucket.list_blobs(prefix=bucket_prefix)
+        subdir_len = len(str(bucket_prefix).split("/")) + 1
 
         filenames = list()
         if prefix_start and not prefix_end:
@@ -113,6 +122,9 @@ def gs_bucket_list_patterns(project_id, bucket_name,
         elif not prefix_start and not prefix_start:
             filenames = list(sorted([str(blob.name) for blob in blobs]))
 
+        if subdir:
+            filenames = [filename for filename in filenames if len(str(filename).split("/")) == subdir_len]
+
         if logging:
             logging.info(cons.txt_gs_bucket_list_patterns_success.format(bucket_name))
             cprint(cons.txt_gs_bucket_list_patterns_success.format(bucket_name), 'yellow')
