@@ -6,7 +6,8 @@ from etl_bq_tools.utils import constants as cons
 def upload_df_to_bq(
         project_id, table_full_id, key_path, partition_column=None,
         schema=None, df=None, if_exists="truncate", logging=None):
-    """
+    """This method is for upload df to bigquery
+
      :param project_id: String
      :param table_full_id: String -> 'project.dataset.table'
      :param key_path: file.json
@@ -15,8 +16,9 @@ def upload_df_to_bq(
      :param df: Dataframe
      :param if_exists: String -> "append" or "truncate"
      :param logging: object
-     :return:
+     :return: job result
     """
+
     from google.cloud import bigquery
     from google.api_core.exceptions import Conflict
     import pandas as pd
@@ -60,16 +62,17 @@ def upload_df_to_bq(
         job = client.load_table_from_dataframe(
             df, table_id, job_config=job_config
         )
-        job.result()
 
         if logging:
             logging.info(cons.txt_upload_df_to_bq_success.format(table_id))
             cprint(cons.txt_upload_df_to_bq_success.format(table_id), 'yellow')
         else:
             cprint(cons.txt_upload_df_to_bq_success.format(table_id), 'yellow')
+        return job.result()
     except Conflict:
         if logging:
             logging.info(cons.txt_upload_df_to_bq_errors.format(table_id))
             cprint(cons.txt_upload_df_to_bq_errors.format(table_id), 'yellow')
         else:
             cprint(cons.txt_upload_df_to_bq_errors.format(table_id), 'yellow')
+        return None
\ No newline at end of file
