@@ -7,13 +7,16 @@ from etl_bq_tools.utils.time_execution import get_time_function_execution
 @get_time_function_execution
 def show_describe_dataset(project_id=None, dataset_full_id="",
                           logging=None, key_path=None, show_table=False):
-    """
+    """This method is describe dataset
+
      :param project_id: String
      :param dataset_full_id: String {project}.{dateset}
      :param logging: object
      :param key_path: file.json
      :param show_table: False
+     :return: DataFrame
     """
+
     from color_tools import cprint
     from sizebytes_tools import convert_bytes
 
@@ -70,3 +73,4 @@ def show_describe_dataset(project_id=None, dataset_full_id="",
             cprint(cons.txt_show_describe_table_errors.format(f"{dataset_full_id}"), "yellow")
         else:
             cprint(cons.txt_show_describe_table_errors.format(f"{dataset_full_id}"), "yellow")
+        return None
