@@ -1,8 +1,7 @@
 def get_logger(filename):
     """
-    :param project_path: path_root
     :param filename: file.txt
-    :return:
+    :return: logger
     """
     import logging
 
